@@ -1,9 +1,10 @@
 package Search::Tools::QueryParser;
-use Moo;
-extends 'Search::Tools::Object';
+use strict;
+use warnings;
+use base qw( Search::Tools::Object );
 use Carp;
 use Data::Dump qw( dump );
-use Search::Query::Parser;
+use Search::QueryParser;
 use Encode;
 use Data::Dump;
 use Search::Tools::Query;
@@ -11,9 +12,7 @@ use Search::Tools::UTF8;
 use Search::Tools::XML;
 use Search::Tools::RegEx;
 
-use namespace::sweep;
-
-our $VERSION = '0.999_04';
+our $VERSION = '0.24';
 
 my $XML = Search::Tools::XML->new();
 my $C2E = $XML->char2ent_map;
@@ -33,48 +32,52 @@ my ( $locale, $lang, $charset );
 }
 
 my %Defaults = (
-    and_word                => q/and|near\d*/,
+    locale                  => $locale,
     charset                 => $charset,
-    default_field           => "",
-    ignore_case             => 1,
-    ignore_fields           => {},
+    lang                    => $lang,
+    stopwords               => [],
+    wildcard                => q/*/,
+    term_re                 => qr/\w+(?:'\w+)*/,
+    word_characters         => q/\w/ . quotemeta(q/'-/),
     ignore_first_char       => quotemeta(q/'-/),
     ignore_last_char        => quotemeta(q/'-/),
-    lang                    => $lang,
-    locale                  => $locale,
-    not_word                => q/not/,
-    or_word                 => q/or/,
-    phrase_delim            => q/"/,
-    query_class             => 'Search::Tools::Query',
-    query_dialect           => "Search::Query::Dialect::Native",
-    stemmer                 => undef,
-    stopwords               => [],
     tag_re                  => $XML->tag_re,
-    term_re                 => qr/\w+(?:[\'\-]\w+)*/,
-    term_min_length         => 1,
-    treat_uris_like_phrases => 1,
     whitespace              => $XML->html_whitespace,
-    wildcard                => q/*/,
-    word_characters         => q/\w/ . quotemeta(q/'-/),
+    stemmer                 => undef,
+    phrase_delim            => q/"/,
+    ignore_case             => 1,
+    and_word                => q/and|near\d*/,
+    or_word                 => q/or/,
+    not_word                => q/not/,
+    ignore_fields           => {},
+    treat_uris_like_phrases => 1,
 );
 
-for my $attr ( keys %Defaults ) {
-    has( $attr => ( is => 'rw', default => sub { $Defaults{$attr} } ) );
-}
-has 'start_bound'        => ( is => 'ro' );
-has 'end_bound'          => ( is => 'ro' );
-has 'plain_phrase_bound' => ( is => 'ro' );
-has 'html_phrase_bound'  => ( is => 'ro' );
+__PACKAGE__->mk_accessors( keys %Defaults );
+__PACKAGE__->mk_ro_accessors(
+    qw(
+        start_bound
+        end_bound
+        plain_phrase_bound
+        html_phrase_bound
+        )
+);
 
 sub get_defaults {
     return {%Defaults};
 }
 
-sub BUILD {
+sub init {
     my $self = shift;
+    $self->SUPER::init(@_);
 
     # TODO handle case where both term_re and word_characters are defined
 
+    for ( keys %Defaults ) {
+        next if defined $self->{$_};
+        $self->{$_} = $Defaults{$_};
+    }
+
     # charset/locale/lang are a bit interdependent
     # so make sure charset/lang are set if locale is explicitly passed.
     if ( $self->{locale} ne $Defaults{locale} ) {
@@ -95,95 +98,67 @@ sub BUILD {
 }
 
 sub parse {
-    my $self      = shift;
-    my $query_str = shift;
-    confess "query required" unless defined $query_str;
+    my $self = shift;
+    my $query_str = shift or croak "query required";
     if ( ref $query_str ) {
         croak "query must be a scalar string";
     }
-
-    #$query_str = to_utf8( $query_str, $self->charset );
     my $extracted = $self->_extract_terms($query_str);
     my %regex;
-TERM: for my $term ( @{ $extracted->{terms} } ) {
-        my ( $plain, $html, $escaped ) = $self->_build_regex($term);
-        my $is_phrase = $term =~ m/\ /;
-        my @phrase_terms;
-
-        # if the term is a phrase,
-        # build regex for each term in the phrase
-        if ($is_phrase) {
-            my @pts = split( /\ /, $term );
-            for my $pt (@pts) {
-                my ( $pt_plain, $pt_html, $pt_esc )
-                    = $self->_build_regex($pt);
-                push @phrase_terms,
-                    Search::Tools::RegEx->new(
-                    plain     => $pt_plain,
-                    html      => $pt_html,
-                    term      => $pt,
-                    term_re   => qr/$pt_esc/i,
-                    is_phrase => 0,
-                    );
-            }
-        }
+    for my $term ( @{ $extracted->{terms} } ) {
+        my ( $plain, $html ) = $self->_build_regex($term);
         $regex{$term} = Search::Tools::RegEx->new(
-            plain        => $plain,
-            html         => $html,
-            term         => $term,
-            term_re      => qr/$escaped/i,
-            is_phrase    => $is_phrase,
-            phrase_terms => \@phrase_terms,
+            plain     => $plain,
+            html      => $html,
+            term      => $term,
+            is_phrase => ( $term =~ m/\ / ? 1 : 0 ),
         );
-
     }
-    return $self->{query_class}->new(
-        dialect => $extracted->{dialect},
-        terms   => $extracted->{terms},
-        fields  => $extracted->{fields},
-        str     => to_utf8( $query_str, $self->charset ),
-        regex   => \%regex,
-        qp      => $self,
+    return Search::Tools::Query->new(
+        search_queryparser => $extracted->{parser},
+        terms              => $extracted->{terms},
+        str                => $query_str,
+        regex              => \%regex,
+        qp                 => $self,
     );
 }
 
 sub _extract_terms {
-    my $self  = shift;
-    my $query = shift;
-    confess "need query to extract terms" unless defined $query;
-    my $stopwords     = $self->stopwords;
-    my $and_word      = $self->and_word;
-    my $or_word       = $self->or_word;
-    my $not_word      = $self->not_word;
-    my $wildcard      = $self->wildcard;
-    my $phrase        = $self->phrase_delim;
-    my $igf           = $self->ignore_first_char;
-    my $igl           = $self->ignore_last_char;
-    my $wordchar      = $self->word_characters;
-    my $default_field = $self->default_field;
-    my $esc_wildcard  = quotemeta($wildcard);
-    my $word_re       = qr/(($esc_wildcard)?[$wordchar]+($esc_wildcard)?)/;
-    my $min_length    = $self->term_min_length;
-    my $raw_query     = $query;
+    my $self      = shift;
+    my $query     = shift or croak "need query to extract terms";
+    my $stopwords = $self->stopwords;
+    my $and_word  = $self->and_word;
+    my $or_word   = $self->or_word;
+    my $not_word  = $self->not_word;
+    my $wildcard  = $self->wildcard;
+    my $phrase    = $self->phrase_delim;
+    my $igf       = $self->ignore_first_char;
+    my $igl       = $self->ignore_last_char;
+    my $wordchar  = $self->word_characters;
+
+    my $esc_wildcard = quotemeta($wildcard);
+    my $word_re      = qr/([$wordchar]+($esc_wildcard)?)/;
+
+    # backcompat allows for query to be array ref.
+    # this called only from S::T::Keywords
+    my @query = @{ ref $query ? $query : [$query] };
 
     $stopwords = [ split( /\s+/, $stopwords ) ] unless ref $stopwords;
     my %stophash = map { to_utf8( lc($_), $self->charset ) => 1 } @$stopwords;
     my ( %words, %uniq, $c );
-    my $parser = Search::Query::Parser->new(
-        and_regex     => qr{$and_word}i,
-        or_regex      => qr{$or_word}i,
-        not_regex     => qr{$not_word}i,
-        default_field => $default_field,
-        query_class   => $self->query_dialect,
+    my $parser = Search::QueryParser->new(
+        rxAnd => qr{$and_word}i,
+        rxOr  => qr{$or_word}i,
+        rxNot => qr{$not_word}i,
     );
 
-    my $baked_query = $raw_query;
-    $baked_query = lc($baked_query) if $self->ignore_case;
-    $baked_query = to_utf8( $baked_query, $self->charset );
-    my $dialect = $parser->parse($baked_query) or croak $parser->error;
-    $self->debug && carp "parsetree: " . Data::Dump::dump( $dialect->tree );
-    my $fields_searched
-        = $self->_get_value_from_tree( \%uniq, $dialect->tree, $c );
+Q: for my $q (@query) {
+        $q = lc($q) if $self->ignore_case;
+        $q = to_utf8( $q, $self->charset );
+        my $tree = $parser->parse( $q, 1 ) or croak $parser->err;
+        $self->debug && carp "parsetree: " . Data::Dump::dump($tree);
+        $self->_get_value_from_tree( \%uniq, $tree, $c );
+    }
 
     $self->debug && carp "parsed: " . Data::Dump::dump( \%uniq );
 
@@ -206,7 +181,7 @@ U: for my $u ( sort { $uniq{$a} <=> $uniq{$b} } keys %uniq ) {
         if ( $self->treat_uris_like_phrases ) {
 
             # special case: treat email addresses, uris, as phrase
-            $isphrase ||= $u =~ m/[$wordchar][\@\.\\\/][$wordchar]/ || 0;
+            $isphrase ||= $u =~ m/[$wordchar][\@\.\\][$wordchar]/ || 0;
         }
 
         $self->debug && carp "$u -> isphrase = $isphrase";
@@ -223,8 +198,8 @@ U: for my $u ( sort { $uniq{$a} <=> $uniq{$b} } keys %uniq ) {
                 my $tok = _untaint($1);
 
                 # strip ignorable chars
-                $tok =~ s/^[$igf]+// if length($igf);
-                $tok =~ s/[$igl]+$// if length($igl);
+                $tok =~ s/^[$igf]+//;
+                $tok =~ s/[$igl]+$//;
 
                 unless ($tok) {
                     $self->debug && carp "no token for '$w' $word_re";
@@ -284,12 +259,6 @@ U: for my $u ( sort { $uniq{$a} <=> $uniq{$b} } keys %uniq ) {
             # since the * will match both
             delete( $words{$copy} );
         }
-
-        if ( length $_ < $min_length ) {
-            $self->debug and carp "token too short: '$_'";
-            delete $words{$_};
-        }
-
     }
 
     $self->debug && carp "wildcards removed: " . Data::Dump::dump( \%words );
@@ -309,16 +278,23 @@ U: for my $u ( sort { $uniq{$a} <=> $uniq{$b} } keys %uniq ) {
         W: for my $w (@w) {
                 my $func = $self->stemmer;
                 my $f = &$func( $self, $w );
-                if ( !defined $f or !length $f ) {
-                    next W;
-                }
-                $f = to_utf8($f);
 
                 #warn "w: $w\nf: $f\n";
 
+                if ( $f ne $w ) {
+
+                    my @stemmed = split //, $f;
+                    my @char    = split //, $w;
+                    $f = '';    #reset
+                    while ( @char && @stemmed && $stemmed[0] eq $char[0] ) {
+                        $f .= shift @stemmed;
+                        shift @char;
+                    }
+
+                }
+
                 # add wildcard to indicate chars were lost
                 $w = $f . $wildcard;
-
             }
             my $new = join ' ', @w;
             if ( $new ne $_ ) {
@@ -333,10 +309,9 @@ U: for my $u ( sort { $uniq{$a} <=> $uniq{$b} } keys %uniq ) {
 
     # sort keeps query in same order as we entered
     return {
-        terms => [ sort { $words{$a} <=> $words{$b} } keys %words ],
-        fields  => [ keys %$fields_searched ],
-        dialect => $dialect,
-        query   => $raw_query,
+        terms  => [ sort     { $words{$a} <=> $words{$b} } keys %words ],
+        parser => $parser,
+        query  => join( ' ', @query ),
     };
 
 }
@@ -365,53 +340,20 @@ sub _get_value_from_tree {
     my $uniq      = shift;
     my $parseTree = shift;
     my $c         = shift;
-    my %fields    = ();
 
     # we only want the values from non minus queries
-    for my $node ( '+', '' ) {
-        next unless exists $parseTree->{$node};
-
+    for my $node ( grep { $_ eq '+' || $_ eq '' } keys %$parseTree ) {
         my @branches = @{ $parseTree->{$node} };
 
-        #warn dump \@branches;
-
         for my $leaf (@branches) {
             my $v = $leaf->{value};
-            if ( !defined $v ) {
-                croak "undefined value in query tree: " . dump($leaf);
-            }
-            if ( defined $leaf->{field}
-                and exists $self->ignore_fields->{ $leaf->{field} } )
-            {
-                next;
-            }
-            my $field = $leaf->{field};
-            if ( defined $field ) {
-                $fields{$field}++;
-            }
-            if ( ref $v eq 'HASH' ) {
-                my $f = $self->_get_value_from_tree( $uniq, $v, $c );
-                $fields{$_} = $f->{$_} for ( keys %$f );
-            }
-            elsif ( ref $v eq 'ARRAY' ) {
-                for my $value (@$v) {
-                    $value =~ s/\s+/ /g;
-                    $uniq->{$value} = ++$c;
-                }
+            next if exists $self->ignore_fields->{ $leaf->{field} };
+
+            if ( ref $v ) {
+                $self->_get_value_from_tree( $uniq, $v, $c );
             }
             else {
 
-                # if the $leaf is a proximity query,
-                # ignore the "phrase-ness" of it and split
-                # on whitespace. This is a compromise,
-                # mitigated by the tendency of HeatMap
-                # to reward proximity anyway.
-                if ( $leaf->{proximity} and $leaf->{proximity} > 1 ) {
-                    my @tokens = split( m/\ +/, $v );
-                    $uniq->{$_} = ++$c for @tokens;
-                    next;
-                }
-
                 # collapse any whitespace
                 $v =~ s,\s+,\ ,g;
 
@@ -419,7 +361,7 @@ sub _get_value_from_tree {
             }
         }
     }
-    return \%fields;
+
 }
 
 sub _setup_regex_builder {
@@ -459,13 +401,14 @@ sub _setup_regex_builder {
                             # this might give unexpected results.
                             # NOTE that &nbsp; etc is in $WhiteSpace
         $html_whitespace,
-        '[^' . $wordchars . ']'
+        '[^' . $wordchars . ']',
+        qr/[$ignore_first]+/i
     );
-    push( @start_bound, qr/[$ignore_first]+/i ) if length $ignore_first;
 
-    my @end_bound
-        = ( '\Z', '[<&]', $html_whitespace, '[^' . $wordchars . ']' );
-    push( @end_bound, qr/[$ignore_last]+/i ) if length $ignore_last;
+    my @end_bound = (
+        '\Z', '[<&]', $html_whitespace, '[^' . $wordchars . ']',
+        qr/[$ignore_last]+/i
+    );
 
     $self->{start_bound} ||= join( '|', @start_bound );
 
@@ -476,22 +419,14 @@ sub _setup_regex_builder {
     #	one or more nonwordchar or whitespace, followed by
     #	any ignore_first_char
     # define for both text and html
-    # NOTE the first/last swap for plain vs html
-    # is intentional because of how regex are built.
 
-    my @plain_phrase_bound = (
-        ( length($ignore_last) ? qr/[$ignore_last]*/i : '' ),
-        qr/(?:[\s\x20]|[^$wordchars])+/is,
-        ( length($ignore_first) ? qr/[$ignore_first]?/i : '' ),
-    );
-    $self->{plain_phrase_bound} = join( '', @plain_phrase_bound );
+    $self->{plain_phrase_bound} = join( '',
+        qr/[$ignore_last]*/i, qr/[\s\x20]|[^$wordchars]/is,
+        qr/[$ignore_first]?/i );
 
-    my @html_phrase_bound = (
-        ( length($ignore_first) ? qr/[$ignore_first]*/i : '' ),
-        qr/(?:$html_whitespace|[^$wordchars])+/is,
-        ( length($ignore_last) ? qr/[$ignore_last]?/i : '' ),
-    );
-    $self->{html_phrase_bound} = join( '', @html_phrase_bound );
+    $self->{html_phrase_bound} = join( '',
+        qr/[$ignore_first]*/i, qr/$html_whitespace|[^$wordchars]/is,
+        qr/[$ignore_last]?/i );
 
 }
 
@@ -534,7 +469,7 @@ ${escaped}
 CHAR: foreach my $c (@char) {
         $counter++;
 
-        my $ent = $C2E->{$c} || undef;
+        my $ent = $C2E->{$c} || carp "no entity defined for >$c< !\n";
         my $num = ord($c);
 
         # if this is a special regexp char, protect it
@@ -548,13 +483,7 @@ CHAR: foreach my $c (@char) {
             next CHAR;
         }
 
-        my $aka;
-        if ($ent) {
-            $aka = $ent eq "&#$num;" ? $ent : "$ent|&#$num;";
-        }
-        else {
-            $aka = "&#$num;";
-        }
+        my $aka = $ent eq "&#$num;" ? $ent : "$ent|&#$num;";
 
         # make $c into a regexp
         $c = qr/$c|$aka/i unless $c eq "[$wild]*";
@@ -580,7 +509,7 @@ ${end_bound}
 )
 /xis;
 
-    return ( $plain, $html, $escaped );
+    return ( $plain, $html );
 }
 
 sub _build_term_re {
@@ -633,7 +562,6 @@ Search::Tools::QueryParser - convert string queries into objects
             word_characters     => q/\w\'\-/,
             ignore_first_char   => q/\+\-/,
             ignore_last_char    => q/\+\-/,
-            term_min_length     => 1,
             
         # words to ignore
             stopwords           => [qw( the )],
@@ -658,14 +586,9 @@ Search::Tools::QueryParser - convert string queries into objects
     );
     
  my $query    = $qparser->parse(q(the quick color:brown "fox jumped"));
- my $terms    = $query->terms; # ['quick', 'brown', '"fox jumped"']
- 
- # a Search::Tools::RegEx object
- my $regexp   = $query->regexp_for($terms->[0]); 
- 
- # the Search::Query::Dialect tree()
- my $tree     = $query->tree;
- 
+ my $terms = $query->terms; # ['quick', 'brown', '"fox jumped"']
+ my $regexp   = $query->regexp_for($terms->[0]); # S::T::R::Keyword
+ my $tree     = $query->tree; # the Search::QueryParser-parsed struct
  print "$query\n";  # the quick color:brown "fox jumped"
  print $query->str . "\n"; # same thing
  
@@ -676,12 +599,16 @@ Search::Tools::QueryParser turns search queries into objects that can
 be applied for highlighting, spelling, and extracting matching snippets
 from source documents.
 
+This is a new class in Search::Tools version 0.24. It supercedes
+the Search::Tools::RegExp and Search::Tools::Keywords public API, but
+backwords compatability is preserved except where noted.
+
 =head1 METHODS
 
 =head2 new( %opts )
 
-The new() method instantiates a QueryParser object. With the exception
-of parse(), all the following methods can be passed as key/value
+The new() method instantiates a S::T::K object. With the exception
+of extract(), all the following methods can be passed as key/value
 pairs in new().
 
 =head2 init
@@ -741,8 +668,6 @@ will be tokenized into words based on whitespace, then the stopwords removed.
 
 =head2 term_re
 
-=head2 term_min_length
-
 =head2 whitespace
 
 =head2 word_characters
@@ -772,12 +697,6 @@ would parse the query:
 
  site:foo.bar AND baz   # terms = baz
 
-=head2 default_field
-
-Set the default field to be used in parsing the query, if no field
-is specified. The default is the empty string (the Search::Query::Parser
-default).
-
 =head2 treat_uris_like_phrases
 
 Boolean (default true (1)).
@@ -815,16 +734,6 @@ Base language. If not set, extracted from C<locale> or defaults to C<en_US>.
 Base charset used for converting queries to UTF-8. If not set, 
 extracted from C<locale> or defaults to C<iso-8859-1>.
 
-=head2 query_class
-
-The default is C<Search::Tools::Query> but you can set your own to subclass
-the Query object.
-
-=head2 query_dialect
-
-The default is C<Search::Query::Dialect::Native> but you can set your own.
-See the L<Search::Query::Dialect> documentation.
-
 =head1 LIMITATIONS
 
 The special HTML chars &, < and > can pose problems in regexps against markup, so they
@@ -880,4 +789,4 @@ same terms as Perl itself.
 
 =head1 SEE ALSO
 
-Search::Query::Parser
+Search::QueryParser
