@@ -1,31 +1,22 @@
 package Search::Tools::RegEx;
-use Moo;
-extends 'Search::Tools::Object';
+use strict;
+use warnings;
+use base qw( Search::Tools::Object );
 use Carp;
-use overload
-    '""'     => sub { $_[0]->term; },
-    'bool'   => sub {1},
-    fallback => 1;
 
 #use Data::Dump qw( dump );
 
-use namespace::sweep;
+our $VERSION = '0.24';
 
-our $VERSION = '0.999_04';
-
-my @ro_attrs = qw(
-    plain
-    html
-    term
-    term_re
-    is_phrase
-    phrase_terms
+__PACKAGE__->mk_ro_accessors(
+    qw(
+        plain
+        html
+        term
+        is_phrase
+        )
 );
 
-for my $attr (@ro_attrs) {
-    has $attr => ( is => 'ro' );
-}
-
 =head1 NAME
 
 Search::Tools::RegEx - regular expressions for terms
@@ -49,16 +40,8 @@ Search::Tools::RegEx - regular expressions for terms
 
 =head2 term
 
-=head2 term_re
-
 =head2 is_phrase
 
-=head2 phrase_terms
-
-If B<is_phrase> is true, B<phrase_terms> will contain an ARRAY ref
-of Search::Tools::RegEx objects, each one representing a term
-in the phrase.
-
 =cut
 
 1;
@@ -114,4 +97,4 @@ same terms as Perl itself.
 
 =head1 SEE ALSO
 
-Search::Tools::Query
+Search::Tools::QUery
