@@ -1,5 +1,7 @@
 package Search::Tools::Token;
-use Moo;
+use strict;
+use warnings;
+use Carp;
 use overload
     '""'     => sub { $_[0]->str; },
     'bool'   => sub { $_[0]->len; },
@@ -7,7 +9,11 @@ use overload
 
 use Search::Tools;    # XS required
 
-our $VERSION = '0.999_04';
+our $VERSION = '0.24';
+
+sub is_end_of_sentence {
+    return $_[0] =~ m/[\.\?\!\;\:]\ /;
+}
 
 1;
 
@@ -71,21 +77,11 @@ Did the token match the re() in the Tokenizer.
 
 Did the token match the heat_seeker in the Tokenizer.
 
-=head2 is_sentence_start
-
-Returns true value if the Token starts with an UPPER case
-UTF8 character or other common sentence-starting character.
-
-=head2 is_sentence_end
+=head2 is_end_of_sentence
 
 Returns true value if the Token matches common sentence-ending
 punctuation.
 
-=head2 is_abbreviation
-
-Returns true value if the Token looks like a common English
-abbreviation.
-
 =head2 dump
 
 Prints the internal XS attributes to stderr.
