@@ -1,17 +1,16 @@
 package Search::Tools::TokenList;
-use Moo;
-with 'Search::Tools::TokenListUtils';
+use strict;
+use warnings;
 use overload
     '""'     => sub { $_[0]->str; },
-    'bool'   => sub { 1 }, # always true
+    'bool'   => sub { $_[0]->len; },
     fallback => 1;
 
 use Search::Tools;    # XS required
 use Carp;
+use base qw( Search::Tools::TokenListUtils );
 
-use namespace::sweep;
-
-our $VERSION = '0.999_04';
+our $VERSION = '0.24';
 
 1;
 
@@ -126,16 +125,11 @@ Prints internal XS attributes to stderr.
 
 =head2 get_heat
 
-Returns an array ref to the internal AV (array) of positions with
+Returns an array ref to the internal AV (array) of tokens with
 is_hot() set by the original Tokenizer. This method will return an
 empty list unless you have passed a heat_seeker to the tokenize() method.
 See Search::Tools::Tokenizer.
 
-=head2 get_sentence_starts
-
-Returns an array ref to the internal AV (array) of sentence start
-positions for each position in get_heat().
-
 =head2 matches
 
 Returns an array ref of all the Tokens with is_match() set. The
