@@ -1,17 +1,17 @@
 package Search::Tools::TokenListPP;
-use Moo;
-extends 'Search::Tools::Object';
+use strict;
+use warnings;
+use base qw( Search::Tools::Object );
 use overload
     '""'     => sub { $_[0]->str; },
     'bool'   => sub { $_[0]->len; },
     fallback => 1;
 use Carp;
-with 'Search::Tools::TokenListUtils';
+use base qw( Search::Tools::TokenListUtils );
 
-our $VERSION = '0.999_04';
+our $VERSION = '0.24';
 
-has 'pos' => ( is => 'rw' );
-has 'num' => ( is => 'rw' );
+__PACKAGE__->mk_accessors(qw( pos num ));
 
 sub len {
     return scalar @{ $_[0]->{tokens} };
@@ -26,10 +26,10 @@ sub next {
     my $tokens = $self->{tokens};
     my $len    = scalar(@$tokens) - 1;
     if ( $len == -1 ) {
-        return;
+        return undef;
     }
     elsif ( $self->{pos} > $len ) {
-        return;
+        return undef;
     }
     else {
         return $tokens->[ $self->{pos}++ ];
@@ -41,10 +41,10 @@ sub prev {
     my $tokens = $self->{tokens};
     my $len    = scalar(@$tokens) - 1;
     if ( $len == -1 ) {
-        return;
+        return undef;
     }
     elsif ( $self->{pos} < 0 ) {
-        return;
+        return undef;
     }
     else {
         return $tokens->[ --$self->{pos} ];
@@ -67,7 +67,7 @@ sub get_token {
         croak "index position required";
     }
     if ( !defined $self->{tokens}->[$i] ) {
-        return;
+        return undef;
     }
     else {
         return $self->{tokens}->[$i];
