@@ -1,8 +1,9 @@
 package Search::Tools::TokenListUtils;
-use Moo::Role;
+use strict;
+use warnings;
 use Carp;
 
-our $VERSION = '0.999_04';
+our $VERSION = '0.24';
 
 =head1 NAME
 
@@ -38,7 +39,7 @@ by both Search::Tools::TokenList and Search::Tools::TokenListPP.
 
 Returns a serialized version of the TokenList. If you haven't
 altered the TokenList since you got it from tokenize(),
-then str() returns a scalar string identical to (but not the same as)
+then str() returns a scalar string identical to (but not the same)
 the string you passed to tokenize().
 
 Both Search::Tools::TokenList and TokenListPP are overloaded
@@ -55,7 +56,7 @@ sub str {
     return join( $joiner, map {"$_"} @{ $self->as_array } );
 }
 
-=head2 get_window( I<pos> [, I<size>, I<as_sentence>] )
+=head2 get_window( I<pos> [, I<size>] )
 
 Returns array with two values: I<start> and I<end> positions
 for the array of length I<size> on either side of I<pos>. 
@@ -70,9 +71,6 @@ side of I<pos>. So the entire window width (length of the returned
 slice) is I<size>*2 +/-1. The window is guaranteed to be bounded
 by B<matches>.
 
-If I<as_sentence> is true, the window is shifted to try and match
-the first token prior to I<pos> that returns true for is_sentence_start().
-
 =cut
 
 sub get_window {
@@ -82,9 +80,8 @@ sub get_window {
         croak "pos required";
     }
 
-    my $size        = int(shift) || 20;
-    my $as_sentence = shift      || 0;
-    my $max_index   = $self->len - 1;
+    my $size = int(shift) || 20;
+    my $max_index = $self->len - 1;
 
     if ( $pos > $max_index or $pos < 0 ) {
         croak "illegal pos value: no such index in TokenList";
@@ -107,46 +104,12 @@ sub get_window {
     $start ||= 0;
     $end   ||= $max_index;
 
-    if ($as_sentence) {
-        my $sentence_starts = $self->get_sentence_starts;
-
-        # default to what we have.
-        my $start_for_pos = $start;
-        my $i             = 0;
-
-        #warn "looking for sentence_start for start = $start end = $end\n";
-        for (@$sentence_starts) {
-
-            #warn " $_ [$i]\n";
-            if ( $_ >= $pos ) {
-                $start_for_pos = $sentence_starts->[$i];
-                last;
-            }
-            $i++;
-        }
-
-        #warn "found $start_for_pos (start = $start end = $end)\n";
-        if ( $start_for_pos != $start ) {
-            if ( $start_for_pos < $start ) {
-                $end -= ( $start - $start_for_pos );
-            }
-            else {
-                $end += ( $start_for_pos - $start );
-            }
-            $start = $start_for_pos;
-        }
-
-        #warn "now $start_for_pos (start = $start end = $end)\n";
+    # make sure window starts and ends with is_match
+    while ( !$self->get_token($start)->is_match ) {
+        $start++;
     }
-    else {
-
-        # make sure window starts and ends with is_match
-        while ( !$self->get_token($start)->is_match ) {
-            $start++;
-        }
-        while ( !$self->get_token($end)->is_match ) {
-            $end--;
-        }
+    while ( !$self->get_token($end)->is_match ) {
+        $end--;
     }
 
     #warn "return $start .. $end";
@@ -172,62 +135,6 @@ sub get_window_tokens {
     return \@slice;
 }
 
-=head2 as_sentences([I<stringified>])
-
-Returns a reference to an array of arrays,
-where each child array is a "sentence" worth of Token objects.
-You can stringify each sentence array like:
-
- my $sentences = $tokenlist->as_sentences;
- for my $s (@$sentences) {
-     printf("sentence: %s\n", join("", map {"$_"} @$s));
- }
-
-If you pass a single true value to as_sentences(),
-then the array returned will consist of plain scalar strings
-with whitespace normalized.
-
-=cut
-
-sub as_sentences {
-    my $self = shift;
-    my $stringed = shift || 0;
-    my @sents;
-    my @s;
-
-    # use array method since we do not know the iterator position
-    for my $t ( @{ $self->as_array } ) {
-        if ( $t->is_sentence_start ) {
-
-            # if has any, add anonymous copy to master
-            if (@s) {
-                push @sents, [@s];
-            }
-
-            # reset
-            @s = ();
-        }
-
-        # add
-        push @s, $t;
-    }
-    if (@s) {
-        push @sents, [@s];
-    }
-    if ($stringed) {
-        my @stringed;
-        for my $s (@sents) {
-            my $str = join( "", map {"$_"} @$s );
-            $str =~ s/\s\s+/\ /g;
-            $str =~ s/\s+$//;
-            push @stringed, $str;
-        }
-        return \@stringed;
-    }
-
-    return \@sents;
-}
-
 1;
 
 __END__
