@@ -1,26 +1,24 @@
 package Search::Tools::TokenPP;
-use Moo;
-extends 'Search::Tools::Object';
+use strict;
+use warnings;
+use base qw( Search::Tools::Object );
 use Carp;
 use overload
     '""'     => sub { $_[0]->str; },
     'bool'   => sub { $_[0]->len; },
     fallback => 1;
 
-use namespace::sweep;
+our $VERSION = '0.24';
 
-our $VERSION = '0.999_04';
-
-my @attrs
-    = qw( is_match is_hot pos str len u8len is_sentence_start is_sentence_end );
-
-for my $attr (@attrs) {
-    has $attr => ( is => 'rw' );
-}
+__PACKAGE__->mk_accessors(qw( is_match is_hot pos str len u8len ));
 
 sub set_hot   { $_[0]->is_hot( $_[1] ); }
 sub set_match { $_[0]->is_match( $_[1] ); }
 
+sub is_end_of_sentence {
+    return $_[0] =~ m/[\.\?\!\;\:]\ /;
+}
+
 1;
 
 __END__
@@ -83,9 +81,7 @@ Did the token match the re() in the Tokenizer.
 
 Did the token match the heat_seeker in the Tokenizer.
 
-=head2 is_sentence_start
-
-=head2 is_sentence_end
+=head2 is_end_of_sentence
 
 Returns true value if the Token matches common sentence-ending
 punctuation.
