@@ -1,18 +1,21 @@
 package Search::Tools::Tokenizer;
-use Moo;
-extends 'Search::Tools::Object';
+use strict;
+use warnings;
+use base qw( Search::Tools::Object );
 use Search::Tools;    # XS package required
 use Search::Tools::Token;
 use Search::Tools::TokenList;
 use Search::Tools::UTF8;
 use Carp;
 
-our $VERSION = '0.999_04';
+our $VERSION = '0.24';
 
-has 're' => ( is => 'rw', default => sub {qr/\w+(?:[\'\-\.]\w+)*/} );
+__PACKAGE__->mk_accessors(qw( re ));
 
-sub BUILD {
+sub init {
     my $self = shift;
+    $self->SUPER::init(@_);
+    $self->{re} ||= qr/\w+(?:'\w+)*/;
     if ( $self->debug ) {
         $self->set_debug( $self->debug - 1 );    # XS debug a level higher
     }
@@ -44,7 +47,6 @@ sub tokenize_pp {
     my $heat_seeker_is_coderef
         = ( defined $heat_seeker and ref($heat_seeker) eq 'CODE' ) ? 1 : 0;
 
-    # TODO is_sentence_* logic
     for ( split( m/($re)/, $_[0] ) ) {
         next unless length($_);
         my $tok = bless(
@@ -52,7 +54,7 @@ sub tokenize_pp {
                 str      => $_,
                 is_hot   => 0,
                 is_match => 0,
-                len      => byte_length($_),
+                len      => bytes::length($_),
                 u8len    => length($_),
             },
             'Search::Tools::TokenPP'
@@ -133,22 +135,11 @@ you set this once in new(). The default value is:
 
 which will match words and contractions (e.g., "do", "not" and "don't").
 
-=head2 tokenize( I<string> [, I<heat_seeker>, I<match_num>] )
+=head2 tokenize( I<string> )
 
 Returns a TokenList object representin the Tokens in I<string>.
 I<string> is "split" according to the regex in re().
 
-I<heat_seeker> can be either a CODE reference or a regex object (qr//)
-to use for testing is_hot per token. An example CODE reference:
-
- my $tokens = $tokenizer->tokenize('foo bar', sub { 
-    my ($token) = @_;
-    # do something with token during initial iteration
- },);
-
-I<match_num> is the parentheses number to consider the matching token
-in the re() value. The default is 0 (the entire matching pattern).
-
 =head2 tokenize_pp( I<string> )
 
 Returns a TokenListPP object.
@@ -158,11 +149,6 @@ see what the XS algorithm does, if you are so inclined, and so the author
 could benchmark the two implementations and thereby feel some satisfaction 
 at having spent the time writing the XS/C version (2-3x faster than Perl).
 
-=head2 get_offsets( I<string>, I<regex> )
-
-Returns an array ref of pos() values for start offsets of I<regex> within
-I<string>
-
 =head2 set_debug( I<n> )
 
 Sets the XS debugger on. By default, setting debug(1) (which is inherited
