@@ -20,9 +20,9 @@ our @EXPORT = qw(
 
 );
 
-our $Debug = 0;
+our $Debug = $ENV{PERL_DEBUG} || 0;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub to_utf8 {
     my $str = shift;
@@ -239,25 +239,63 @@ converting to UTF-8 if necessary. Returns I<text> encoded and flagged as UTF-8.
 Returns undef if for some reason the encoding failed or the result did not pass
 is_sane_utf8().
 
-=head1 BUGS
-
 =head1 AUTHOR
 
-Peter Karman C<perl@peknet.com>
+Peter Karman C<< <karman@cpan.org> >>
+
+Originally based on the HTML::HiLiter regular expression building code, 
+by the same author, copyright 2004 by Cray Inc.
 
 Thanks to Atomic Learning C<www.atomiclearning.com> 
-for sponsoring the development of this module.
+for sponsoring the development of some of these modules.
 
 Many of the UTF-8 tests come directly from Test::utf8.
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-search-tools at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Search-Tools>.  
+I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Search::Tools
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Search-Tools>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Search-Tools>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Search-Tools>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Search-Tools/>
+
+=back
+
 =head1 COPYRIGHT
 
-Copyright 2007 by Peter Karman. 
+Copyright 2006-2009 by Peter Karman.
+
 This package is free software; you can redistribute it and/or modify it under the 
 same terms as Perl itself.
 
 =head1 SEE ALSO
 
-Search::Tools, Encode, Test::utf8
+HTML::HiLiter, SWISH::HiLiter, Rose::Object, Class::XSAccessor, Text::Aspell
 
 =cut
